@@ -1,5 +1,6 @@
 #!/usr/bin/env Rscript
 # Copyright 2010-2013 Trevor L Davis <trevor.l.davis@stanford.edu>
+# Copyright 2013 Kirill Müller 
 #  
 #  This file is free software: you may copy, redistribute and/or modify it  
 #  under the terms of the GNU General Public License as published by the  
@@ -21,16 +22,9 @@ option_list <- list(
     )
 parser <- OptionParser(usage = "%prog [options] file", option_list=option_list)
 
-arguments <- parse_args(parser, positional_arguments = TRUE)
+arguments <- parse_args(parser, positional_arguments = 1)
 opt <- arguments$options
-
-if(length(arguments$args) != 1) {
-    cat("Incorrect number of required positional arguments\n\n")
-    print_help(parser)
-    stop()
-} else {
-    file <- arguments$args
-}
+file <- arguments$args
 
 if( file.access(file) == -1) {
     stop(sprintf("Specified file ( %s ) does not exist", file))
